embassy-stm32

Crates

git

Versions

stm32h7a3lg

Flavors

OCTOSPI1

Struct OCTOSPI1 

pub struct OCTOSPI1 { /* private fields */ }
OCTOSPI1 peripheral

Implementations

Source

impl OCTOSPI1

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.